import { MigrationInterface, QueryRunner, Table, TableForeignKey } from "typeorm";
import { DB_TYPE } from "../env.defaults";

export class Permissions1724661484664 implements MigrationInterface {
  name = "Permissions1724661484664";

  public async up(queryRunner: QueryRunner): Promise<void> {
    const variableType_int = DB_TYPE == "mysql" ? "int" : "integer";

    await queryRunner.createTable(
      new Table({
        name: "permission",
        columns: [
          {
            name: "permission",
            type: "varchar",
            length: "255",
            isPrimary: true,
            isNullable: false,
          },
          { name: "userId", type: variableType_int, isPrimary: true, isNullable: false },
        ],
      }),
      true
    );

    await queryRunner.createForeignKey(
      "permission",
      new TableForeignKey({
        columnNames: ["userId"],
        referencedColumnNames: ["id"],
        referencedTableName: "user",
        onDelete: "CASCADE",
        onUpdate: "RESTRICT",
      })
    );
  }

  public async down(queryRunner: QueryRunner): Promise<void> {
    const table = await queryRunner.getTable("permission");
    const foreignKey = table.foreignKeys.find((fk) => fk.columnNames.indexOf("userId") !== -1);
    await queryRunner.dropForeignKey("permission", foreignKey);
    await queryRunner.dropTable("permission");
  }
}
