import { dataSource } from "../data-source";
import { newsletterConfig } from "../entity/newsletterConfig";
import { member } from "../entity/member";
import InternalException from "../exceptions/internalException";

export default abstract class NewsletterConfigService {
  /**
   * @description get all newsletterConfigs
   * @returns {Promise<Array<newsletterConfig>>}
   */
  static async getAll(): Promise<Array<newsletterConfig>> {
    return await dataSource
      .getRepository(newsletterConfig)
      .createQueryBuilder("newsletterConfig")
      .leftJoinAndSelect("newsletterConfig.comType", "comType")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("newsletterConfigs not found", err);
      });
  }

  /**
   * @description get newsletterConfig by id
   * @returns {Promise<newsletterConfig>}
   */
  static async getByComId(comId: number): Promise<newsletterConfig> {
    return await dataSource
      .getRepository(newsletterConfig)
      .createQueryBuilder("newsletterConfig")
      .leftJoinAndSelect("newsletterConfig.comType", "comType")
      .where("newsletterConfig.comTypId = :comTypId", { icomTypId: comId })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("newsletterConfig not found by cmId", err);
      });
  }
}
